import * as i0 from '@angular/core';
import { Injectable, EventEmitter, Component, ViewChild, NgModule } from '@angular/core';
import { AsyncSubject, of, delay, BehaviorSubject } from 'rxjs';
import { Human as Human$1, Env as Env$1 } from 'ngx-scanner-face-human';

/**
 * Frame speed ms/fps.
 */
const FPS = 30;
/**
 * setTimeout 1000ms.
 */
const TIMEOUT_DETECT = 1000;
/**
 * user configuration for human, used to fine-tune behavior
 */
const CONFIG = {
    async: false,
    modelBasePath: './models',
    filter: {
        flip: false
    },
    face: {
        enabled: true,
        detector: {
            rotation: false,
        },
        mesh: {
            enabled: true,
        },
        attention: {
            enabled: false,
        },
        iris: {
            enabled: true,
        },
        description: {
            enabled: true,
        },
        emotion: {
            enabled: true,
        },
    },
    body: { enabled: true },
    hand: { enabled: true },
    object: { enabled: false },
    gesture: { enabled: true },
};
/**
 * Env class that holds detected capabilities
 */
const ENV = {
    perfadd: false, // is performance data showing instant or total values
};
/**
 * Draw Options
 */
const DRAW_OPTIONS = {
    font: 'monospace',
    lineHeight: 20,
};
/**
 * MediaStream
s * https://developer.mozilla.org/en-US/docs/Web/API/MediaDevices/getUserMedia
 */
const MEDIASTREAM = {
    audio: false,
    video: true
};

/**
 * Override Config
 */
const OVERRIDES = (defaultConfig, switchConfig) => {
    if (switchConfig && Object.keys(switchConfig)?.length) {
        for (const key in defaultConfig) {
            switchConfig = switchConfig?.hasOwnProperty(key)
                ? switchConfig
                : JSON.parse(JSON.stringify({
                    ...switchConfig,
                    ...{ [key]: defaultConfig[key] },
                }));
        }
        return switchConfig;
    }
    else {
        return defaultConfig;
    }
};
/**
 * AS_COMPLETE
 * @param as
 * @param data
 * @param error
 */
const AS_COMPLETE = (as, data, error) => {
    error ? as.error(error) : as.next(data);
    as.complete();
};
/**
 * Download from url
 * @param url
 */
const DOWNLOAD = (url, fileName) => {
    const link = document.createElement('a');
    link.download = fileName;
    link.href = url;
    link.click();
};
/**
 * Clean and reset canvas
 * @param canvas
 */
const RESET_CANVAS = (canvas) => {
    // reset canvas
    const context = canvas.getContext('2d', { willReadFrequently: true });
    // clear frame when reloop
    context.clearRect(0, 0, canvas.width, canvas.height);
};
/**
 * COMPRESS_IMAGE_FILE
 * @param files
 * @param percentage
 * @param quality
 * @returns
 */
const COMPRESS_IMAGE_FILE = (files = [], percentage = 100, quality = 100) => {
    if (files.length && (percentage < 100 || quality < 100)) {
        // Have files
        const resizedFiles = [];
        return new Promise((resolve, reject) => {
            for (const file of files) {
                const image = new Image();
                const reader = new FileReader();
                reader.onload = function (event) {
                    image.onload = function () {
                        const canvas = document.createElement('canvas');
                        const ctx = canvas.getContext('2d');
                        const newWidth = Math.round(image.width * (percentage / 100));
                        const newHeight = Math.round(image.height * (percentage / 100));
                        canvas.width = newWidth;
                        canvas.height = newHeight;
                        ctx.drawImage(image, 0, 0, newWidth, newHeight);
                        canvas.toBlob((blob) => {
                            const resizedFile = new File([blob], file.name, { type: file.type });
                            resizedFiles.push(resizedFile);
                            if (files.length === resizedFiles.length) {
                                resolve(resizedFiles);
                            }
                        }, file.type, quality / 100);
                    };
                    image.src = event.target.result;
                };
                reader.onerror = (error) => reject(error);
                reader.readAsDataURL(file);
            }
        });
    }
    else {
        // No files selected
        return Promise.resolve(files);
    }
};
/**
 * DRAW_IMAGE
 * @param canvas
 * @param image
 */
const DRAW_IMAGE = (canvas, image) => {
    canvas.width = image.width;
    canvas.height = image.height;
    const ctx = canvas.getContext('2d');
    ctx.drawImage(image, 0, 0, canvas.width, canvas.height);
};
/**
 * UPDATE_WIDTH_HEIGHT_VIDEO
 * @param video
 * @param canvas
 */
const UPDATE_WIDTH_HEIGHT_VIDEO = (video, canvas) => {
    canvas.setAttribute('width', video.videoWidth + '');
    canvas.setAttribute('height', video.videoHeight + '');
};

class NgxScannerFaceService {
    /**
     * Files to base64: ScannerFaceResult[]
     * @param files
     * @param ScannerFaceResult
     * @returns ScannerFaceResult
     */
    toBase64(files) {
        const result = new AsyncSubject();
        const data = [];
        if (files?.length) {
            Object.keys(files)?.forEach((file, i) => {
                const url = URL.createObjectURL(files[i]);
                const reader = new FileReader();
                reader.readAsDataURL(files[i]);
                reader.onload = (e) => {
                    data.push({
                        name: files[i]?.name,
                        file: files[i],
                        base64: reader?.result,
                        url: url,
                    });
                    if (files?.length === i + 1) {
                        result.next(data);
                        result.complete();
                    }
                };
            });
            return result;
        }
        else {
            result.next([]);
            result.complete();
            return result;
        }
    }
    /**
     * loadFiles
     * @param files
     * @param baseConfig
     * @param quality
     * @param type
     * @returns
     */
    loadFiles(files = [], baseConfig, percentage, quality) {
        const as = new AsyncSubject();
        this.overrideConfig(baseConfig);
        COMPRESS_IMAGE_FILE(files, percentage, quality).then((_files) => {
            Promise.all([..._files].map((m) => this.readAsDataURL(m, baseConfig))).then((img) => AS_COMPLETE(as, img)).catch((error) => AS_COMPLETE(as, null, error));
        });
        return as;
    }
    /**
     * readAsDataURL
     * @param file
     * @param baseConfig
     * @returns
     */
    readAsDataURL(file, baseConfig) {
        /** drawImage **/
        return new Promise((resolve, reject) => {
            let fileReader = new FileReader();
            fileReader.onload = () => {
                // Set the src of this Image object.
                const image = new Image();
                // Setting cross origin value to anonymous
                image.setAttribute('crossOrigin', 'anonymous');
                // Set src
                image.src = URL.createObjectURL(file);
                // When our image has loaded.
                image.onload = async () => {
                    // Get the canvas element by using the getElementById method.
                    const canvas = document.createElement('canvas');
                    // new Human
                    let human = new Human$1(baseConfig.human); // create instance of human with overrides from user configuration
                    // draw
                    const draw = async () => {
                        // main screen refresh loop
                        let interpolated = await human.next(human.result); // smoothen result using last-known results
                        // Update width heigth folow result human
                        image.height = interpolated.height;
                        image.width = interpolated.width;
                        // Add image into canvas
                        DRAW_IMAGE(canvas, image);
                        await human.draw.all(canvas, interpolated); // draw labels, boxes, lines, etc.
                        canvas.toBlob((blob) => {
                            resolve({
                                ...interpolated,
                                name: file?.name,
                                file: file,
                                url: URL.createObjectURL(blob),
                                blob: blob,
                            });
                        });
                    };
                    // Detect width and height
                    await human.detect(image);
                    // Draw all
                    of(true).pipe(delay(baseConfig.timeoutDetect || 0)).subscribe(async () => await draw());
                };
            };
            fileReader.onerror = (error) => reject(error);
            fileReader.readAsDataURL(file);
        });
    }
    /**
     * Override Config
     */
    overrideConfig(baseConfig) {
        const isNull = (field) => baseConfig?.[field] == null || baseConfig?.[field] == undefined;
        if (isNull('fps'))
            baseConfig.fps = FPS;
        if (isNull('timeoutDetect'))
            baseConfig.timeoutDetect = TIMEOUT_DETECT;
        if (isNull('isAuto'))
            baseConfig.isAuto = false;
        if (isNull('env'))
            baseConfig.env = ENV;
        if (isNull('draw'))
            baseConfig.draw = DRAW_OPTIONS;
        if (isNull('human'))
            baseConfig.human = CONFIG;
        if (isNull('constraints'))
            baseConfig.constraints = MEDIASTREAM;
    }
    /**
     * StreamToBase64
     * @param result
     * @returns
     */
    streamToBase64(result) {
        const as = new AsyncSubject();
        if (result) {
            let canvas = document.createElement('canvas');
            canvas.width = result?.canvas?.width ?? 0;
            canvas.height = result?.canvas?.height ?? 0;
            const H = new Human$1();
            H.draw.canvas(result.canvas, canvas); // draw processed image to screen canvas
            H.draw.all(canvas, result); // draw labels, boxes, lines, etc.
            as.next({ ...result, base64: canvas.toDataURL() });
            as.complete();
        }
        return as;
    }
    /**
     * StreamToBlobURL
     * @param result
     * @returns
     */
    streamToBlobURL(result) {
        const as = new AsyncSubject();
        if (result) {
            let canvas = document.createElement('canvas');
            canvas.width = result?.canvas?.width ?? 0;
            canvas.height = result?.canvas?.height ?? 0;
            const H = new Human$1();
            H.draw.canvas(result.canvas, canvas); // draw processed image to screen canvas
            H.draw.all(canvas, result); // draw labels, boxes, lines, etc.
            canvas.toBlob((blob) => {
                as.next({ ...result, blobUrl: URL.createObjectURL(blob) });
                as.complete();
            });
        }
        return as;
    }
    static { this.ɵfac = i0.ɵɵngDeclareFactory({ minVersion: "12.0.0", version: "16.2.12", ngImport: i0, type: NgxScannerFaceService, deps: [], target: i0.ɵɵFactoryTarget.Injectable }); }
    static { this.ɵprov = i0.ɵɵngDeclareInjectable({ minVersion: "12.0.0", version: "16.2.12", ngImport: i0, type: NgxScannerFaceService, providedIn: 'root' }); }
}
i0.ɵɵngDeclareClassMetadata({ minVersion: "12.0.0", version: "16.2.12", ngImport: i0, type: NgxScannerFaceService, decorators: [{
            type: Injectable,
            args: [{
                    providedIn: 'root',
                }]
        }] });

/**
 * @default ngx-scanner-face
 * @author <DaiDH>
 * @package https://www.npmjs.com/package/ngx-scanner-face
 * @license MIT https://github.com/id1945/ngx-scanner-face/blob/master/LICENSE
 * @copyright <https://github.com/id1945>
*/
class NgxScannerFaceComponent {
    constructor() {
        /**
         * EventEmitter
         */
        this.event = new EventEmitter();
        /**
         * Input
         */
        this.src = '';
        this.isAuto = false; // Auto start camera.
        this.fps = FPS; // Frame speed ms/fps.
        this.timeoutDetect = TIMEOUT_DETECT; // setTimeout 1000ms.
        this.constraints = MEDIASTREAM;
        this.env = {};
        this.draw = {};
        this.human = {};
        this.config = {};
        this.style = null;
        this.videoStyle = null;
        this.canvasStyle = null;
        /**
         * Export
        */
        this.isStart = false;
        this.isPause = false;
        this.isLoading = false;
        this.isTorch = false;
        this.data = new BehaviorSubject({});
        this.devices = new BehaviorSubject([]);
        this.deviceIndexActive = 0;
        this.STATUS = {
            startON: () => this.isStart = true,
            pauseON: () => this.isPause = true,
            loadingON: () => this.isLoading = true,
            startOFF: () => this.isStart = false,
            pauseOFF: () => this.isPause = false,
            loadingOFF: () => this.isLoading = false,
            torchOFF: () => this.isTorch = false,
        };
    }
    ngOnInit() {
        this.overrideConfig();
        if (this.src) {
            this.loadImage(this.src);
        }
        else if (this.isAuto) {
            this.start();
        }
    }
    /**
     * start
     * @param playDeviceCustom
     * @returns
     */
    start(playDeviceCustom) {
        const as = new AsyncSubject();
        if (this.isStart) {
            // Reject
            AS_COMPLETE(as, false);
        }
        else {
            // fix safari
            this.safariWebRTC(as, playDeviceCustom);
        }
        return as;
    }
    /**
     * playDevice
     * @param deviceId
     * @param as
     * @returns
     */
    playDevice(deviceId, as = new AsyncSubject()) {
        const existDeviceId = this.isStart ? this.getConstraints().deviceId !== deviceId : true;
        switch (true) {
            case deviceId === 'null' || deviceId === 'undefined' || !deviceId:
                stop();
                this.stop();
                AS_COMPLETE(as, false);
                break;
            case deviceId && existDeviceId:
                stop();
                this.stop();
                // Loading on
                this.STATUS.loadingON();
                this.deviceIndexActive = this.devices.value.findIndex((f) => f.deviceId === deviceId);
                const constraints = { ...this.constraints, audio: false, video: { deviceId: deviceId, ...this.constraints.video } };
                // MediaStream
                const run = async () => {
                    try {
                        // new Human
                        this.H_OBJ = new Human$1(this.human); // create instance of human with overrides from user configuration
                        this.overrideEnv(this.H_OBJ);
                        this.overrideDraw(this.H_OBJ);
                        // grab instances of dom objects so we dont have to look them up later
                        const dom = {
                            video: this.video.nativeElement,
                            canvas: this.canvas.nativeElement
                        };
                        const webCam = async () => {
                            const stream = await navigator.mediaDevices.getUserMedia(constraints);
                            const ready = new Promise((resolve) => { dom.video.onloadeddata = () => resolve(true); });
                            dom.video.srcObject = stream;
                            void dom.video.play();
                            await ready;
                            dom.canvas.width = dom.video.videoWidth;
                            dom.canvas.height = dom.video.videoHeight;
                        };
                        this.detectionLoop = async () => {
                            if (this.isStart && !this.isPause) {
                                await this.H_OBJ.detect(dom.video); // actual detection; were not capturing output in a local variable as it can also be reached via human.result
                                setTimeout(async () => await this.detectionLoop(), this.fps);
                            }
                        };
                        this.drawLoop = async () => {
                            if (this.isStart && !this.isPause) {
                                this.interpolated = { ...this.H_OBJ.result, canvas2: dom.canvas, base64: '' }; // smoothen result using last-known results
                                RESET_CANVAS(dom.canvas);
                                // draw only frame
                                await this.H_OBJ.draw.all(dom.canvas, this.interpolated); // draw labels, boxes, lines, etc.
                                this.interpolated.base64 = dom.canvas.toDataURL();
                                this.eventEmit(this.interpolated);
                                setTimeout(async () => await this.drawLoop(), this.fps); // use to slow down refresh from max refresh rate to target of 30 fps
                            }
                        };
                        await this.H_OBJ.warmup(); // warmup function to initialize backend for future faster detection
                        await webCam(); // start webcam
                        this.STATUS.startON();
                        this.STATUS.loadingOFF();
                        await this.detectionLoop(); // start detection loop
                        await this.drawLoop(); // start draw loop
                        AS_COMPLETE(as, true);
                    }
                    catch (error) {
                        this.STATUS.startOFF();
                        this.STATUS.loadingOFF();
                        this.eventEmit(null);
                        AS_COMPLETE(as, false, error);
                    }
                };
                run();
                break;
            default:
                AS_COMPLETE(as, false);
                this.STATUS.loadingOFF();
                break;
        }
        return as;
    }
    /**
     * stop
     * @return AsyncSubject
     */
    stop() {
        this.STATUS.pauseOFF();
        this.STATUS.startOFF();
        this.STATUS.torchOFF();
        this.STATUS.loadingOFF();
        const as = new AsyncSubject();
        try {
            this.video?.nativeElement?.srcObject?.getTracks()?.forEach((track) => {
                track?.stop();
                AS_COMPLETE(as, true);
                DRAW_IMAGE(this.canvas.nativeElement, createImageBitmap(this.video?.nativeElement));
            });
        }
        catch (error) {
            AS_COMPLETE(as, false, error);
        }
        return as;
    }
    /**
     * play
     * @return AsyncSubject
     */
    play() {
        const as = new AsyncSubject();
        if (this.isPause) {
            this.video?.nativeElement?.play();
            this.STATUS.pauseOFF();
            this.detectionLoop();
            this.drawLoop();
            AS_COMPLETE(as, true);
        }
        else {
            AS_COMPLETE(as, false);
        }
        return as;
    }
    /**
     * pause
     * @return AsyncSubject
     */
    pause() {
        const as = new AsyncSubject();
        if (this.isStart) {
            this.video?.nativeElement?.pause();
            this.STATUS.pauseON();
            AS_COMPLETE(as, true);
        }
        else {
            AS_COMPLETE(as, false);
        }
        return as;
    }
    /**
     * torcher
     * @returns
     */
    torcher() {
        const as = this.applyConstraints({ advanced: [{ torch: this.isTorch }] });
        as.subscribe(() => false, () => this.isTorch = !this.isTorch);
        return as;
    }
    /**
     * loadImage
     * @param src
     */
    loadImage(src) {
        let as = new AsyncSubject();
        // hidden video element
        this.canvas.nativeElement.style.backgroundColor = '#262626';
        this.canvas.nativeElement.style.width = '';
        this.canvas.nativeElement.style.position = '';
        this.canvas.nativeElement.style.maxWidth = '100%';
        this.video.nativeElement.style.display = 'none';
        // Set the src of this Image object.
        const image = new Image();
        // Setting cross origin value to anonymous
        image.setAttribute('crossOrigin', 'anonymous');
        // Set src
        image.src = src;
        // When our image has loaded.
        image.onload = async () => {
            // Loading on
            this.STATUS.startOFF();
            this.STATUS.loadingON();
            // new Human
            let human = new Human$1(this.human); // create instance of human with overrides from user configuration
            this.overrideEnv(human);
            this.overrideDraw(human);
            // draw
            const draw = async () => {
                // main screen refresh loop
                let interpolated = await human.next(human.result); // smoothen result using last-known results
                // Update width heigth folow result human
                image.height = interpolated.height;
                image.width = interpolated.width;
                // draw frame on image
                DRAW_IMAGE(this.canvas.nativeElement, image);
                // draw all
                await human.draw.all(this.canvas.nativeElement, interpolated); // draw labels, boxes, lines, etc.
                interpolated.canvas2 = this.canvas.nativeElement;
                interpolated.base64 = this.canvas.nativeElement.toDataURL();
                this.eventEmit(interpolated);
                this.STATUS.startOFF();
                this.STATUS.loadingOFF();
                AS_COMPLETE(as, true);
            };
            // Detect width and height
            await human.detect(image);
            // Draw all
            of(true).pipe(delay(this.timeoutDetect)).subscribe(async () => await draw());
        };
        // error
        image.onerror = (error) => AS_COMPLETE(as, false, error);
        return as;
    }
    /**
     * applyConstraints
     * @param constraints
     * @param deviceIndex
     * @returns
     */
    applyConstraints(constraints, deviceIndex = 0) {
        const as = new AsyncSubject();
        if (this.isStart) {
            const stream = this.video.nativeElement.srcObject;
            if (deviceIndex !== null || deviceIndex !== undefined || !Number.isNaN(deviceIndex)) {
                const videoTrack = stream.getVideoTracks()[deviceIndex];
                const imageCapture = new window.ImageCapture(videoTrack);
                imageCapture.getPhotoCapabilities().then(async () => {
                    await videoTrack.applyConstraints(constraints);
                    const SCALE = setInterval(() => UPDATE_WIDTH_HEIGHT_VIDEO(this.video.nativeElement, this.canvas.nativeElement), 1000);
                    setTimeout(() => clearInterval(SCALE), 3000);
                    AS_COMPLETE(as, true);
                }).catch((error) => {
                    switch (error?.name) {
                        case 'NotFoundError':
                        case 'DevicesNotFoundError':
                            AS_COMPLETE(as, false, 'Required track is missing');
                            break;
                        case 'NotReadableError':
                        case 'TrackStartError':
                            AS_COMPLETE(as, false, 'Webcam or mic are already in use');
                            break;
                        case 'OverconstrainedError':
                        case 'ConstraintNotSatisfiedError':
                            AS_COMPLETE(as, false, 'Constraints can not be satisfied by avb. devices');
                            break;
                        case 'NotAllowedError':
                        case 'PermissionDeniedError':
                            AS_COMPLETE(as, false, 'Permission denied in browser');
                            break;
                        case 'TypeError':
                            AS_COMPLETE(as, false, 'Empty constraints object');
                            break;
                        default:
                            AS_COMPLETE(as, false, error);
                            break;
                    }
                });
            }
            else {
                AS_COMPLETE(as, false, 'Please check again deviceIndex');
            }
        }
        else {
            AS_COMPLETE(as, false, 'Please start the scanner');
        }
        return as;
    }
    ;
    /**
     * getConstraints
     * @param deviceIndex
     * @returns
     */
    getConstraints(deviceIndex = 0) {
        const stream = this.video.nativeElement.srcObject;
        const videoTrack = stream?.getVideoTracks()[deviceIndex];
        return videoTrack?.getConstraints();
    }
    /**
     * download
     * @param fileName
     * @return AsyncSubject
     */
    download(fileName = `ngx_scanner_face_${Date.now()}.png`) {
        const as = new AsyncSubject();
        const canvas = document.createElement('canvas');
        canvas.width = this.video.nativeElement.videoWidth;
        canvas.height = this.video.nativeElement.videoHeight;
        // draw labels, boxes, lines, etc.
        (async () => {
            // Draw frame on origin element canvas (this.interpolated.canvas is origin)
            await this.H_OBJ.draw.canvas(this.interpolated.canvas, canvas); // draw processed image to screen canvas
            // draw human
            await this.H_OBJ.draw.all(canvas, this.interpolated);
            // toBlob and emit data
            const dataURL = canvas.toDataURL(`image/${fileName?.split('.')?.slice(-1)?.toString()}`);
            canvas.toBlob((blob) => {
                DOWNLOAD(dataURL, fileName);
                AS_COMPLETE(as, {
                    ...this.interpolated,
                    url: URL.createObjectURL(blob),
                    canvas2: canvas,
                    base64: dataURL
                });
            });
        })();
        return as;
    }
    /**
     * Override Config
     */
    overrideConfig() {
        this.fps = this.config?.fps ?? this.fps ?? FPS;
        this.timeoutDetect = this.config?.timeoutDetect ?? this.timeoutDetect ?? TIMEOUT_DETECT;
        this.isAuto = this.config?.isAuto ?? this.isAuto ?? false;
        this.env = OVERRIDES(ENV, this.config?.env ?? this.env);
        this.draw = OVERRIDES(DRAW_OPTIONS, this.config?.draw ?? this.draw);
        this.human = OVERRIDES(CONFIG, this.config?.human ?? this.human);
        this.constraints = OVERRIDES(MEDIASTREAM, this.config?.constraints ?? this.constraints);
    }
    /**
     * Override Env
     * @return void
     */
    overrideEnv(human) {
        // Set env
        for (const key in this.env) {
            human.env[key] = this.env[key];
        }
    }
    /**
     * Override drawOptions
     * @return void
     */
    overrideDraw(human) {
        // Set drawOptions
        for (const key in this.draw) {
            human.draw.options[key] = this.draw[key];
        }
    }
    /**
     * Fix issue on safari
     * https://webrtchacks.com/guide-to-safari-webrtc
     * @param as
     * @param playDeviceCustom
     */
    safariWebRTC(as, playDeviceCustom) {
        // Loading on
        this.STATUS.startOFF();
        this.STATUS.loadingON();
        navigator.mediaDevices.getUserMedia(this.constraints).then((stream) => {
            stream.getTracks().forEach(track => track.stop());
            this.loadAllDevices(as, playDeviceCustom);
        }).catch(error => {
            this.STATUS.startOFF();
            this.STATUS.loadingOFF();
            AS_COMPLETE(as, false, error);
        });
    }
    /**
     * loadAllDevices
     * @param as
     * @param playDeviceCustom
     */
    loadAllDevices(as, playDeviceCustom) {
        navigator.mediaDevices.enumerateDevices().then(devices => {
            let cameraDevices = devices.filter(f => f.kind == 'videoinput');
            this.devices.next(cameraDevices);
            if (cameraDevices.length > 0) {
                AS_COMPLETE(as, cameraDevices);
                playDeviceCustom ? playDeviceCustom(cameraDevices) : this.playDevice(cameraDevices[0].deviceId);
            }
            else {
                this.STATUS.startOFF();
                this.STATUS.loadingOFF();
                AS_COMPLETE(as, false, 'No camera detected.');
            }
        }).catch(error => {
            this.STATUS.startOFF();
            this.STATUS.loadingOFF();
            AS_COMPLETE(as, false, error);
        });
    }
    /**
     * eventEmit
     * @param response
     */
    eventEmit(response = false) {
        (response !== false) && this.data.next(response ?? null);
        (response !== false) && this.event.emit(response ?? null);
    }
    ngOnDestroy() {
        this.pause();
    }
    static { this.ɵfac = i0.ɵɵngDeclareFactory({ minVersion: "12.0.0", version: "16.2.12", ngImport: i0, type: NgxScannerFaceComponent, deps: [], target: i0.ɵɵFactoryTarget.Component }); }
    static { this.ɵcmp = i0.ɵɵngDeclareComponent({ minVersion: "14.0.0", version: "16.2.12", type: NgxScannerFaceComponent, selector: "ngx-scanner-face", inputs: { src: "src", isAuto: "isAuto", fps: "fps", timeoutDetect: "timeoutDetect", constraints: "constraints", env: "env", draw: "draw", human: "human", config: "config", style: "style", videoStyle: "videoStyle", canvasStyle: "canvasStyle" }, outputs: { event: "event" }, viewQueries: [{ propertyName: "video", first: true, predicate: ["video"], descendants: true, static: true }, { propertyName: "canvas", first: true, predicate: ["canvas"], descendants: true, static: true }], exportAs: ["scanner"], ngImport: i0, template: `<canvas #canvas [style]="canvasStyle || style" style="position: absolute; width: 100%"></canvas><video #video playsinline [style]="videoStyle || style" style="background-color: #262626; width: 100%"></video><ng-content></ng-content>`, isInline: true, styles: [":host{position:relative}\n"] }); }
}
i0.ɵɵngDeclareClassMetadata({ minVersion: "12.0.0", version: "16.2.12", ngImport: i0, type: NgxScannerFaceComponent, decorators: [{
            type: Component,
            args: [{ selector: 'ngx-scanner-face', template: `<canvas #canvas [style]="canvasStyle || style" style="position: absolute; width: 100%"></canvas><video #video playsinline [style]="videoStyle || style" style="background-color: #262626; width: 100%"></video><ng-content></ng-content>`, inputs: ['src', 'isAuto', 'fps', 'timeoutDetect', 'constraints', 'env', 'draw', 'human', 'config', 'style', 'videoStyle', 'canvasStyle'], outputs: ['event'], exportAs: 'scanner', queries: {
                        video: new ViewChild('video', { static: true }),
                        canvas: new ViewChild('canvas', { static: true })
                    }, styles: [":host{position:relative}\n"] }]
        }] });

// Models
class Env extends Env$1 {
}
class Human extends Human$1 {
}

/**
 * @default ngx-scanner-face
 * @author <DaiDH>
 * @package https://www.npmjs.com/package/ngx-scanner-face
 * @license MIT https://github.com/id1945/ngx-scanner-face/blob/master/LICENSE
 * @copyright <https://github.com/id1945>
*/
class NgxScannerFaceModule {
    static { this.ɵfac = i0.ɵɵngDeclareFactory({ minVersion: "12.0.0", version: "16.2.12", ngImport: i0, type: NgxScannerFaceModule, deps: [], target: i0.ɵɵFactoryTarget.NgModule }); }
    static { this.ɵmod = i0.ɵɵngDeclareNgModule({ minVersion: "14.0.0", version: "16.2.12", ngImport: i0, type: NgxScannerFaceModule, declarations: [NgxScannerFaceComponent], exports: [NgxScannerFaceComponent] }); }
    static { this.ɵinj = i0.ɵɵngDeclareInjector({ minVersion: "12.0.0", version: "16.2.12", ngImport: i0, type: NgxScannerFaceModule }); }
}
i0.ɵɵngDeclareClassMetadata({ minVersion: "12.0.0", version: "16.2.12", ngImport: i0, type: NgxScannerFaceModule, decorators: [{
            type: NgModule,
            args: [{
                    declarations: [
                        NgxScannerFaceComponent
                    ],
                    exports: [
                        NgxScannerFaceComponent
                    ]
                }]
        }] });

/*
 * Public API Surface of ngx-scanner-face
 */

/**
 * Generated bundle index. Do not edit.
 */

export { Env, Human, NgxScannerFaceComponent, NgxScannerFaceModule, NgxScannerFaceService };
//# sourceMappingURL=ngx-scanner-face.mjs.map
